﻿using Connected.Models;
using Microsoft.AspNetCore.Components;

namespace Connected.Components;
public partial class SimpleSelect<ValueType> : InputBase
{
	[Parameter]
	public ValueType Value { get; set; }

	[Parameter]
	public IEnumerable<ValueType> Items { get; set; }

	public IEnumerable<ValueType> OriginalItems { get; set; }

	[Parameter]
	public bool EnableSearch { get; set; } = true;

	private string _searchText { get; set; } = string.Empty;
	public string SearchText
	{
		get
		{
			return _searchText;
		}
		set
		{
			_searchText = value;
			FilterItems();
		}
	}

	private async Task SetSelectedItem(ValueType item)
	{
		//DropDownClassToggle();
		await ValueChanged.InvokeAsync(item);
	}

	private void FilterItems()
	{
		if (string.IsNullOrEmpty(_searchText))
		{
			Items = OriginalItems;
		}
		else
		{
			Items = Items.Where(item => item.ToString().ToLower().Contains(_searchText.ToLower()));
		}
		StateHasChanged();
	}


	[Parameter]
	public EventCallback<ValueType> ValueChanged { get; set; }

	private async Task ChangeValueAsync(ChangeEventArgs args)
	{
		await ValueChanged.InvokeAsync((ValueType)Convert.ChangeType(args.Value, typeof(ValueType)));
	}

	protected override async Task OnParametersSetAsync()
	{
		
		OriginalItems = Items;
		if (_searchText.Length>0) FilterItems();
		await base.OnParametersSetAsync();
	}

	protected override async Task OnInitializedAsync()
	{
		await base.OnInitializedAsync();
		if (Required)
		{
			if (InputAttributes.ContainsKey("required")) InputAttributes.Add("required", true);
		}
	}
}